"""JWST NIRSpec dispersers."""

from unite.instrument.nirspec.disperser import (
    G140H,
    G140M,
    G235H,
    G235M,
    G395H,
    G395M,
    PRISM,
    NIRSpecDisperser,
)

__all__ = [
    'G140H',
    'G140M',
    'G235H',
    'G235M',
    'G395H',
    'G395M',
    'PRISM',
    'NIRSpecDisperser',
]
